@@ -30,12 +30,14 @@ def get_contact_address(redis_client, user, contact, w3: Web3):
                 try:
                     ns = ENS.from_web3(w3)
                     to = ns.address(name)
+                    print(f"get ens: {name} -> {to}")
                     if not to:
-                        return 404, f"Cannot find {name} on ENS"
+                        return 404, f"Cannot find {name} on ENS, or the address format is incorrect."
                 except Exception as e:
                     print(f"get ens error: {e}")
                     return 500, e
-            return 404, f"Cannot find {name} on contact"
+            else:
+                return 404, f"Cannot find {name} on contact, or the address format is incorrect."
     else:
         to = contact
     address = w3.to_checksum_address(to)
